[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [44854] trunk/lib/win64/png: Windows x64 PNG libraries:

Thomas Dinges blender at dingto.org
Tue Mar 13 19:06:53 CET 2012


Revision: 44854
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-blender&revision=44854
Author:   dingto
Date:     2012-03-13 18:06:52 +0000 (Tue, 13 Mar 2012)
Log Message:
-----------
Windows x64 PNG libraries:
* Update to version 1.2.47 for security reasons. 

Modified Paths:
--------------
    trunk/lib/win64/png/include/png.h
    trunk/lib/win64/png/include/pngconf.h
    trunk/lib/win64/png/lib/libpng.lib

Modified: trunk/lib/win64/png/include/png.h
===================================================================
--- trunk/lib/win64/png/include/pngconf.h	2012-03-13 17:58:40 UTC (rev 44853)
+++ trunk/lib/win64/png/include/pngconf.h	2012-03-13 18:06:52 UTC (rev 44854)
@@ -1,8 +1,8 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.2.46 - July 9, 2011
- * Copyright (c) 1998-2011 Glenn Randers-Pehrson
+ * libpng version 1.2.47 - February 18, 2012
+ * Copyright (c) 1998-2012 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
  *

Modified: trunk/lib/win64/png/lib/libpng.lib
===================================================================
(Binary files differ)




More information about the Bf-blender-cvs mailing list
--- trunk/lib/win64/png/include/png.h	2012-03-13 17:58:40 UTC (rev 44853)
+++ trunk/lib/win64/png/include/png.h	2012-03-13 18:06:52 UTC (rev 44854)
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.2.46 - July 9, 2011
- * Copyright (c) 1998-2011 Glenn Randers-Pehrson
+ * libpng version 1.2.47 - February 18, 2012
+ * Copyright (c) 1998-2012 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
  *
@@ -10,7 +10,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.2.46 - July 9, 2011: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -270,6 +270,11 @@
  *    1.2.46rc01-02           13    10246  12.so.0.46[.0]
  *    1.0.56                  10    10056  10.so.0.56[.0]
  *    1.2.46                  13    10246  12.so.0.46[.0]
+ *    1.2.47beta01            13    10247  12.so.0.47[.0]
+ *    1.2.47rc01              13    10247  12.so.0.47[.0]
+ *    1.0.57rc01              10    10057  10.so.0.57[.0]
+ *    1.2.47                  13    10247  12.so.0.47[.0]
+ *    1.0.57                  10    10057  10.so.0.57[.0]
  *
  *    Henceforth the source version will match the shared-library major
  *    and minor numbers; the shared-library major version number will be
@@ -301,7 +306,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.2.46, July 9, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -413,13 +418,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    July 9, 2011
+ *    February 18, 2012
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.2.46 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -475,9 +480,9 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.46"
+#define PNG_LIBPNG_VER_STRING "1.2.47"
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.2.46 - July 9, 2011\n"
+   " libpng version 1.2.47 - February 18, 2012\n"
 
 #define PNG_LIBPNG_VER_SONUM   0
 #define PNG_LIBPNG_VER_DLLNUM  13
@@ -485,7 +490,7 @@
 /* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
 #define PNG_LIBPNG_VER_MAJOR   1
 #define PNG_LIBPNG_VER_MINOR   2
-#define PNG_LIBPNG_VER_RELEASE 46
+#define PNG_LIBPNG_VER_RELEASE 47
 /* This should match the numeric part of the final component of
  * PNG_LIBPNG_VER_STRING, omitting any leading zero:
  */
@@ -515,7 +520,7 @@
  * version 1.0.0 was mis-numbered 100 instead of 10000).  From
  * version 1.0.1 it's    xxyyzz, where x=major, y=minor, z=release
  */
-#define PNG_LIBPNG_VER 10246 /* 1.2.46 */
+#define PNG_LIBPNG_VER 10247 /* 1.2.47 */
 
 #ifndef PNG_VERSION_INFO_ONLY
 /* Include the compression library's header */
@@ -1555,7 +1560,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef png_structp version_1_2_46;
+typedef png_structp version_1_2_47;
 
 typedef png_struct FAR * FAR * png_structpp;
 
@@ -10,7 +10,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.2.46 - July 9, 2011: Glenn
+ *  libpng versions 0.97, January 1998, through 1.2.47 - February 18, 2012: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -301,7 +306,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.2.46, July 9, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.2.47, February 18, 2012, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
@@ -413,13 +418,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.2.46 are Y2K compliant.  It is my belief that earlier
+ *    upward through 1.2.47 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *

Modified: trunk/lib/win64/png/include/pngconf.h
===================================================================